@@ -23,7 +23,7 @@ from sentry_sdk.utils import (
 )
 from sentry_sdk.serializer import serialize
 from sentry_sdk.tracing import trace
-from sentry_sdk.transport import HttpTransport, make_transport
+from sentry_sdk.transport import BaseHttpTransport, make_transport
 from sentry_sdk.consts import (
     DEFAULT_MAX_VALUE_LENGTH,
     DEFAULT_OPTIONS,
@@ -61,6 +61,7 @@ if TYPE_CHECKING:
     from sentry_sdk.metrics import MetricsAggregator
     from sentry_sdk.scope import Scope
     from sentry_sdk.session import Session
+    from sentry_sdk.spotlight import SpotlightClient
     from sentry_sdk.transport import Transport
 
     I = TypeVar("I", bound=Integration)  # noqa: E741
@@ -127,7 +128,11 @@ def _get_options(*args, **kwargs):
         rv["traces_sample_rate"] = 1.0
 
     if rv["event_scrubber"] is None:
-        rv["event_scrubber"] = EventScrubber(send_default_pii=rv["send_default_pii"])
+        rv["event_scrubber"] = EventScrubber(
+            send_default_pii=(
+                False if rv["send_default_pii"] is None else rv["send_default_pii"]
+            )
+        )
 
     if rv["socket_options"] and not isinstance(rv["socket_options"], list):
         logger.warning(
@@ -153,6 +158,8 @@ class BaseClient:
     The basic definition of a client that is used for sending data to Sentry.
     """
 
+    spotlight = None  # type: Optional[SpotlightClient]
+
     def __init__(self, options=None):
         # type: (Optional[Dict[str, Any]]) -> None
         self.options = (
@@ -385,7 +392,6 @@ class _Client(BaseClient):
                 disabled_integrations=self.options["disabled_integrations"],
             )
 
-            self.spotlight = None
             spotlight_config = self.options.get("spotlight")
             if spotlight_config is None and "SENTRY_SPOTLIGHT" in os.environ:
                 spotlight_env_value = os.environ["SENTRY_SPOTLIGHT"]
@@ -427,7 +433,7 @@ class _Client(BaseClient):
             self.monitor
             or self.metrics_aggregator
             or has_profiling_enabled(self.options)
-            or isinstance(self.transport, HttpTransport)
+            or isinstance(self.transport, BaseHttpTransport)
         ):
             # If we have anything on that could spawn a background thread, we
             # need to check if it's safe to use them.
@@ -449,7 +455,11 @@ class _Client(BaseClient):
 
         Returns whether the client should send default PII (Personally Identifiable Information) data to Sentry.
         """
-        return self.options.get("send_default_pii", False)
+        result = self.options.get("send_default_pii")
+        if result is None:
+            result = not self.options["dsn"] and self.spotlight is not None
+
+        return result
 
     @property
     def dsn(self):
@@ -522,7 +532,7 @@ class _Client(BaseClient):
 
         for key in "release", "environment", "server_name", "dist":
             if event.get(key) is None and self.options[key] is not None:
-                event[key] = str(self.options[key]).strip()  # type: ignore[literal-required]
+                event[key] = str(self.options[key]).strip()
         if event.get("sdk") is None:
             sdk_info = dict(SDK_INFO)
             sdk_info["integrations"] = sorted(self.integrations.keys())
@@ -571,7 +581,7 @@ class _Client(BaseClient):
                     self.transport.record_lost_event(
                         "before_send", data_category="error"
                     )
-            event = new_event  # type: ignore
+            event = new_event
 
         before_send_transaction = self.options["before_send_transaction"]
         if (
@@ -601,7 +611,7 @@ class _Client(BaseClient):
                         reason="before_send", data_category="span", quantity=spans_delta
                     )
 
-            event = new_event  # type: ignore
+            event = new_event
 
         return event
 
@@ -751,18 +761,16 @@ class _Client(BaseClient):
 
         :returns: An event ID. May be `None` if there is no DSN set or of if the SDK decided to discard the event for other reasons. In such situations setting `debug=True` on `init()` may help.
         """
-        if hint is None:
-            hint = {}
-        event_id = event.get("event_id")
         hint = dict(hint or ())  # type: Hint
 
-        if event_id is None:
-            event["event_id"] = event_id = uuid.uuid4().hex
         if not self._should_capture(event, hint, scope):
             return None
 
         profile = event.pop("profile", None)
 
+        event_id = event.get("event_id")
+        if event_id is None:
+            event["event_id"] = event_id = uuid.uuid4().hex
         event_opt = self._prepare_event(event, hint, scope)
         if event_opt is None:
             return None
@@ -810,15 +818,16 @@ class _Client(BaseClient):
         for attachment in attachments or ():
             envelope.add_item(attachment.to_envelope_item())
 
+        return_value = None
         if self.spotlight:
             self.spotlight.capture_envelope(envelope)
+            return_value = event_id
 
-        if self.transport is None:
-            return None
+        if self.transport is not None:
+            self.transport.capture_envelope(envelope)
+            return_value = event_id
 
-        self.transport.capture_envelope(envelope)
-
-        return event_id
+        return return_value
 
     def capture_session(
         self, session  # type: Session
