@@ -4,7 +4,7 @@ from inspect import isawaitable
 
 import sentry_sdk
 from sentry_sdk.consts import OP
-from sentry_sdk.integrations import Integration, DidNotEnable
+from sentry_sdk.integrations import _check_minimum_version, Integration, DidNotEnable
 from sentry_sdk.integrations.logging import ignore_logger
 from sentry_sdk.scope import should_send_default_pii
 from sentry_sdk.tracing import TRANSACTION_SOURCE_COMPONENT
@@ -31,13 +31,18 @@ try:
     from strawberry import Schema
     from strawberry.extensions import SchemaExtension  # type: ignore
     from strawberry.extensions.tracing.utils import should_skip_tracing as strawberry_should_skip_tracing  # type: ignore
+    from strawberry.http import async_base_view, sync_base_view  # type: ignore
+except ImportError:
+    raise DidNotEnable("strawberry-graphql is not installed")
+
+try:
     from strawberry.extensions.tracing import (  # type: ignore
         SentryTracingExtension as StrawberrySentryAsyncExtension,
         SentryTracingExtensionSync as StrawberrySentrySyncExtension,
     )
-    from strawberry.http import async_base_view, sync_base_view  # type: ignore
 except ImportError:
-    raise DidNotEnable("strawberry-graphql is not installed")
+    StrawberrySentryAsyncExtension = None
+    StrawberrySentrySyncExtension = None
 
 from typing import TYPE_CHECKING
 
@@ -70,14 +75,7 @@ class StrawberryIntegration(Integration):
     def setup_once():
         # type: () -> None
         version = package_version("strawberry-graphql")
-
-        if version is None:
-            raise DidNotEnable(
-                "Unparsable strawberry-graphql version: {}".format(version)
-            )
-
-        if version < (0, 209, 5):
-            raise DidNotEnable("strawberry-graphql 0.209.5 or newer required.")
+        _check_minimum_version(StrawberryIntegration, version, "strawberry-graphql")
 
         _patch_schema_init()
         _patch_execute()
